<?php
/**
 * Dynamic sidbar on default page
 * Calls the th_metaClass on the post edit screen.
 */
$prefix='th_';
$meta_boxes = array(
      array(
        'id' => 'th-dynamic-meta-box',
        'title' => 'Dynamic Sidebar',
        'pages' => array('page','landing-page'), // custom post type  array('page','post', 'link')
        'context' => 'side',
        'priority' => 'high',
        'fields' => array(
            array(
                'name' => 'Sidebar',
                'id' => $prefix . 'sidebar_dyn',
                'type' => 'radio',
                'std' => 'right',
                'options' => array( array("value" => 'left',"name" => 'Left Sidebar'),
                'options' => 		array("value" => 'right',"name" => 'Right Sidebar'),
                					array("value" => 'no-sidebar',"name" => 'No Sidebar'),
                					)
            )
        )
    )
);
foreach ($meta_boxes as $meta_box) {
    $my_box = new thMetaDataClass($meta_box);
}



$meta_boxes_portfolio = array(
      array(
        'id' => 'th-dynamic-meta-box',
        'title' => 'Custom Link',
        'pages' => array('portfolio'), // custom post type array('page','post', 'link')
        'context' => 'side',
        'priority' => 'low',
        'fields' => array(
            array(
                'name' => __('Link','featured'),
                'id' => $prefix . 'tab_extlink',
                'type' => 'text',
                'std' => '',
                'desc' => __('Add custom link for portfolio title.','featured')
            ),
            array(
                'name' => __('Target Link','featured'),
                'id' => $prefix . 'tab_target',
                'type' => 'checkbox',
                'std' => '',
                'desc' => __('Check to open link in new tab.','featured')
            ),
        )
    )
);
foreach ($meta_boxes_portfolio as $meta_box_port) {
    $meta_box_port = new thMetaDataClass($meta_box_port);
}

class thMetaDataClass {
 
    protected $_meta_box;
 
    // create meta box based on given data
    function __construct($meta_box) {
        $this->_meta_box = $meta_box;
        add_action('admin_menu', array(&$this, 'add'));
 
        add_action('save_post', array(&$this, 'save'));
    }
 
    /// Add meta box for multiple post types
    function add() {
        foreach ($this->_meta_box['pages'] as $page) {
            add_meta_box($this->_meta_box['id'], $this->_meta_box['title'], array(&$this, 'show'), $page, $this->_meta_box['context'], $this->_meta_box['priority']);
        }
    }
 
    // Callback function to show fields in meta box
    function show() {
        global $post;
 
        // Use nonce for verification
        echo '<input type="hidden" name="th_dynamic_custom_box_nonce" value="', wp_create_nonce(basename(__FILE__)), '" />';
 
        echo '<table class="form-table">';
 
        foreach ($this->_meta_box['fields'] as $field) {
            // get current post meta data
            $meta = get_post_meta($post->ID, $field['id'], true);
 
            echo '<tr>',
                    '<th style="width:20%"><label for="', $field['id'], '">', $field['name'], '</label></th>',
                    '<td>';
            switch ($field['type']) {
                case 'text':
                    echo '<input type="text" name="', $field['id'], '" id="', $field['id'], '" value="', $meta ? $meta : $field['std'], '" size="30" style="width:97%" />',
                        '<br />', $field['desc'];
                    break;
                case 'textarea':
                    echo '<textarea name="', $field['id'], '" id="', $field['id'], '" cols="60" rows="4" style="width:97%">', $meta ? $meta : $field['std'], '</textarea>',
                        '<br />', $field['desc'];
                    break;
                case 'select':
                    echo '<select name="', $field['id'], '" id="', $field['id'], '">';
                    foreach ($field['options'] as $option) {
                        echo '<option', $meta == $option ? ' selected="selected"' : '', '>', $option, '</option>';
                    }
                    echo '</select>';
                    break;
                case 'radio':
                    foreach ($field['options'] as $option) {
                    	$checked='';
                    	if($field['std']==$option['value'] && empty($meta)){
                    	   $checked = 'checked="checked"';
                    	}elseif($meta==$option['value']){
                             $checked = 'checked="checked"';
                        }
                       
                        echo '<input type="radio" name="', $field['id'], '" value="', $option['value'], '"', $checked, '/>', $option['name'];
                   		echo '<br />';
                    }
                    break;
                case 'checkbox':
                    echo '<input type="checkbox" name="', $field['id'], '" id="', $field['id'], '"', $meta ? ' checked="checked"' : '', ' />',
                        '<br />', $field['desc'];
                    break;
            }
            echo     '<td>',
                '</tr>';
        }
 
        echo '</table>';
    }
 
    // Save data from meta box
    function save($post_id) {
        // verify nonce
          if (!isset($_POST['th_dynamic_custom_box_nonce']) || !wp_verify_nonce($_POST['th_dynamic_custom_box_nonce'], basename(__FILE__))) {
            return $post_id;
        }
 
        // check autosave
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return $post_id;
        }
 
        // check permissions
        if ('page' == $_POST['post_type']) {
            if (!current_user_can('edit_page', $post_id)) {
                return $post_id;
            }
        } elseif (!current_user_can('edit_post', $post_id)) {
            return $post_id;
        }
 
        foreach ($this->_meta_box['fields'] as $field) {
            $old = get_post_meta($post_id, $field['id'], true);
            $new = $_POST[$field['id']];
 
            if ($new && $new != $old) {
                update_post_meta($post_id, $field['id'], $new);
            } elseif ('' == $new && $old) {
                delete_post_meta($post_id, $field['id'], $old);
            }
        }
    }
}